"""
This is the lower level REST client for Feldera.

This is a thin wrapper around the Feldera REST API.

It is recommended to use the higher level abstractions in the `feldera` package,
instead of using the REST client directly.

"""

from feldera.rest.feldera_client import FelderaClient as FelderaClient
